-- Tables 1 (no foreign keys)

CREATE TABLE IF NOT EXISTS `nations` (
 `id_nation` int(11) NOT NULL auto_increment,
 `nation` varchar(50) NOT NULL,
 `language` varchar(50) NOT NULL,
 PRIMARY KEY(`id_nation`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `genres` (
 `id_genre` int(11) NOT NULL auto_increment,
 `genre` varchar(50) NOT NULL,
 PRIMARY KEY(`id_genre`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `roles` (
 `id_role` int(11) NOT NULL auto_increment,
 `role` varchar(50) NOT NULL,
 PRIMARY KEY(`id_role`)
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

-- Tables 2 (they have foreign keys in Tables 1)

CREATE TABLE IF NOT EXISTS `people` (
 `id_people` int(11) NOT NULL auto_increment,
 `id_nation` int(11) NOT NULL,
 `surname` varchar(50) NOT NULL,
 `name` varchar(50) NOT NULL,
 `birthdate` date NOT NULL,
 PRIMARY KEY(`id_people`),
 FOREIGN KEY(`id_nation`) REFERENCES `nations`(`id_nation`)
   ON UPDATE CASCADE
   ON DELETE NO ACTION
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `movies` (
 `id_movie` int(11) NOT NULL auto_increment,
 `id_nation` int(11) NOT NULL,
 `title` varchar(50) NOT NULL,
 `release_date` date NOT NULL,
 `runtime` int(4) NOT NULL, -- in minutes
 `type` varchar(50) NOT NULL, -- color, 3D, B/W, ...
 PRIMARY KEY(`id_movie`),
 FOREIGN KEY(`id_nation`) REFERENCES `nations`(`id_nation`)
   ON UPDATE CASCADE
   ON DELETE NO ACTION
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

-- RELATIONS (they have foreign keys in Tables 1,2)

CREATE TABLE IF NOT EXISTS `movies_people` (
 `id_movie` int(11) NOT NULL,
 `id_people` int(11) NOT NULL,
 `id_role` int(11) NOT NULL,
 PRIMARY KEY(`id_movie`,`id_people`,`id_role`),
 FOREIGN KEY(`id_movie`) REFERENCES `movies`(`id_movie`)
   ON UPDATE CASCADE
   ON DELETE CASCADE,
 FOREIGN KEY(`id_people`) REFERENCES `people`(`id_people`)
   ON UPDATE CASCADE
   ON DELETE CASCADE,
 FOREIGN KEY(`id_role`) REFERENCES `roles`(`id_role`)
   ON UPDATE CASCADE
   ON DELETE NO ACTION
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `movies_genres` (
 `id_movie` int(11) NOT NULL,
 `id_genre` int(11) NOT NULL,
 PRIMARY KEY(`id_movie`,`id_genre`),
 FOREIGN KEY(`id_movie`) REFERENCES `movies`(`id_movie`)
   ON UPDATE CASCADE
   ON DELETE CASCADE,
 FOREIGN KEY(`id_genre`) REFERENCES `genres`(`id_genre`)
   ON UPDATE CASCADE
   ON DELETE NO ACTION
) ENGINE=InnoDB  DEFAULT CHARSET=utf8;
